@@ -102,7 +102,7 @@ test_that("new_pack_info works", {
 
 
 # new_packs_info -----------------------------------------------------------
-test_that("new_pack_info works", {
+test_that("new_packs_info works", {
   output <- new_packs_info(.names = "data_pack__1",
                            .packs = list(input_pack),
                            .remove_obeyers = input_remove_obeyers)
@@ -110,14 +110,6 @@ test_that("new_pack_info works", {
   expect_true(identical(output, input_packs_info))
 })
 
-test_that("new_pack_info removes names inside `.packs`", {
-  output <- new_packs_info(.names = "data_pack__1",
-                           .packs = list(some_name = input_pack),
-                           .remove_obeyers = input_remove_obeyers)
-
-  expect_true(identical(output, input_packs_info))
-})
-
 
 # as_packs_info -----------------------------------------------------------
 test_that("as_packs_info works", {
@@ -163,7 +155,7 @@ test_that("is_exposure works", {
   expect_false(is_exposure(output_2))
 
   output_3 <- output
-  output_3$packs_info[[1]] <- mean
+  output_3$packs_info[[1]] <- 1L
 
   expect_false(is_exposure(output_3))
 
